SystemOrganization addCategory: #'AmbientTalkST-Benchmarks'!

OstBGMeteorBoard subclass: #ATBGMeteorBoard
	instanceVariableNames: 'pieceActor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBGMeteorBoard methodsFor: 'constructors' stamp: 'StefanMarr 5/13/2013 16:59'!
createMeteorPiece
	^ pieceActor adoptObject: super createMeteorPiece! !

!ATBGMeteorBoard methodsFor: 'constructors' stamp: 'StefanMarr 5/13/2013 16:59'!
createMeteorPieceWithIsland
	^ pieceActor adoptObject: super createMeteorPieceWithIsland! !

!ATBGMeteorBoard methodsFor: 'accessing' stamp: 'StefanMarr 5/13/2013 17:18'!
pieceActor: anActor
	pieceActor := anActor! !

BenchmarkGameSuite subclass: #ATBenchmarkGameSuite
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/11/2013 19:09'!
benchATBinaryTrees
	| bench problemSize treeActor benchActor result |
	problemSize := self problemSize
			ifNotNil: [ self problemSize ]
			ifNil:    [ OstBGBinaryTrees defaultProblemSize ].
	
	treeActor  := self createActor: 'Trees'.
	benchActor := self createActor: 'BenchExec'.
	
	bench  := (benchActor evaluateAsync: [OstBGBinaryTrees new]) read.
	bench  :=  benchActor adoptObject: bench. "just to be sure"
	
	bench binaryTreeFactory: (treeActor adoptObject: OstBGTreeNode).
	
	result := benchActor evaluateAsync: [
		bench binarytrees: problemSize to: (TextStream with: String new).
	].
	
	result await.
	
	treeActor  terminate await.
	benchActor terminate await.
	
	^ result read.! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/11/2013 19:30'!
benchATFannkuchRedux
	| problemSize genActor gen benchActor result |
	problemSize := self problemSize
			ifNotNil: [ self problemSize ]
			ifNil:    [ OstBGFannkuchRedux defaultProblemSize ].

	genActor   := self createActor: 'PermGenRedux'.
	benchActor := self createActor: 'BenchExec'.
	
	gen := (genActor evaluateAsync: [ OstBGPermGeneratorRedux new: problemSize ]) read.
	"For AT we need to make sure it is properly enforced"
	gen := genActor adoptObject: gen.
	
	result := benchActor evaluateAsync: [
		OstBGFannkuchRedux new maxPfannkuchenTo: (TextStream with: String new) with: gen ].
	
	result await.
	
	genActor   terminate await.
	benchActor terminate await.
	
	^ result read.
! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/11/2013 19:35'!
benchATFasta
	| randomnessActor benchActor bodies out bench |
	randomnessActor := self createActor: 'Randomness'.
	benchActor      := self createActor: 'BenchExec'.
	
	(benchActor evaluateAsync: [
		bench := OstBGFasta new.
		out := TextStream with: String new.
		bench out: out ]) read.
	
	bench n: (self problemSize
					ifNotNilDo: [:ps | ps ]
					ifNil:      [ OstBGFasta defaultProblemSize ]).
	
	bench := benchActor adoptObject: bench.
	out   := benchActor adoptObject: out.
	
	bench repeatStreamFact: (randomnessActor adoptObject: OstBGRepeatStream).
	
	(benchActor evaluateAsync: [bench oneHomoSapiensAlu]) await.
	
	bench r: (randomnessActor adoptObject: ((randomnessActor evaluateAsync: [OstBGRandomNumber to: 1]) read)).
	bench randomStreamFact: (randomnessActor adoptObject: OstBGRandomStream).
	
	(benchActor evaluateAsync: [
		bench twoIUBAmbiguityCodes.
		bench threeHomoSapiensFrequency.]) await.
	
	out flush.
	
	randomnessActor terminate await.
	benchActor      terminate await.
	
	^ out contents.! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/13/2013 15:48'!
benchATKNucleotide
	" we are not having actors interacting here, just a single actor executing the benchmark "
	|  problemSize benchActor result |
	problemSize := self problemSize
			ifNotNil: [ self problemSize ]
			ifNil:    [ OstBGKNucleotide defaultProblemSize ].
	
	benchActor := self createActor: 'Bench'.
	
   (benchActor evaluateAsync: [
		| bench input |
		bench  := OstBGKNucleotide new.
		input  := ReadStream on: (BGFastaCache forFasta: problemSize).
		result := TextStream with: String new.
		bench knucleotide5From: input to: result
		]) await.
	
	benchActor terminate await.
	
	^ result! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/13/2013 14:51'!
benchATMandelbrot
	| bench problemSize outActor compActor result |
	problemSize := self problemSize
			ifNotNil: [ self problemSize ]
			ifNil:    [ OstBGMandelbrot defaultProblemSize ].
	
	outActor  := self createActor: 'OutArray'.
	compActor := self createActor: 'Computation'.
	
	bench  := (compActor evaluateAsync: [OstBGMandelbrot new]) read.
	bench  :=  compActor adoptObject: bench. "just to be sure"
	
	result := (outActor evaluateAsync: [OstArray new: problemSize * problemSize / 8]) read.
	result :=  outActor adoptObject: result.
	
	(compActor evaluateAsync: [bench mandelbrot2: problemSize to: result]) await.
	
	compActor terminate await.
	outActor  terminate await.
	
	^ result! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/13/2013 18:26'!
benchATMeteor
	"Only a single actor, interdepencencies to complex to simply actorify it with what we have currently"
	| problemSize benchActor result  |
	problemSize := self problemSize
			ifNotNilDo: [:ps | ps ]
			ifNil:      [ OstBGMeteor defaultProblemSize ].

	benchActor  := self createActor: 'BenchExec'.
	
	result := (benchActor evaluateAsync: [OstBGMeteor meteor: problemSize]) read.
	
	benchActor  terminate await.
	
	^ result! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/11/2013 19:47'!
benchATNBody
	| problemSize bodiesActor bodies benchActor result  |
	problemSize := self problemSize
			ifNotNilDo: [:ps | ps ]
			ifNil:      [ OstBGNBody defaultProblemSize ].

	bodiesActor := self createActor: 'Bodies'.
	benchActor  := self createActor: 'BenchExec'.
	
	bodies := (bodiesActor evaluateAsync: [OstBGNBody new]) read.
	bodies := bodiesActor adoptObject: bodies.
	
	result := benchActor evaluateAsync: [
		OstBGNBody nbody: problemSize with: bodies.].
	
	result await.
	
	bodiesActor terminate await.
	benchActor  terminate await.
	
	^ result read.
! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/13/2013 18:45'!
benchATPiDigits
	"Only a single actor, interdepencencies to complex to simply actorify it with what we have currently"
	| problemSize benchActor piActor bench pi result  |
	problemSize := self problemSize
			ifNotNilDo: [:ps | ps ]
			ifNil:      [ OstBGPiDigits defaultProblemSize ].

	benchActor := self createActor: 'BenchExec'.
	piActor    := self createActor: 'PiActor'.
	
	bench := (benchActor evaluateAsync: [OstBGPiDigits new]) read.
	bench :=  benchActor adoptObject: bench.
	
	pi := (piActor evaluateAsync: [OstBGPiDigitSpigot new]) read.
	pi :=  piActor adoptObject: pi.
	
	result := (benchActor evaluateAsync: [bench piDigitsTo: problemSize with: pi]) read.
	
	benchActor terminate await.
	piActor    terminate await.
	
	^ result! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/13/2013 19:10'!
benchATReverseComplement
	"Only a single actor, interdepencencies to complex to simply actorify it with what we have currently"
	| problemSize benchActor result  |
	problemSize := self problemSize
			ifNotNilDo: [:ps | ps ]
			ifNil:      [ BGReverseComplement defaultProblemSize ].

	benchActor  := self createActor: 'BenchExec'.
	
	result := (benchActor evaluateAsync: [BGReverseComplement revcomp: problemSize]) read.
	
	benchActor  terminate await.
	
	^ result! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 5/13/2013 19:09'!
benchATSpectralNorm
	"Only a single actor, interdepencencies to complex to simply actorify it with what we have currently"
	| problemSize benchActor result  |
	problemSize := self problemSize
			ifNotNilDo: [:ps | ps ]
			ifNil:      [ OstBGSpectralNorm defaultProblemSize ].

	benchActor  := self createActor: 'BenchExec'.
	
	result := (benchActor evaluateAsync: [OstBGSpectralNorm new spectralnorm: problemSize]) read.
	
	benchActor  terminate await.
	
	^ result! !

!ATBenchmarkGameSuite methodsFor: 'tracing' stamp: 'StefanMarr 1/4/2012 13:44'!
createActor: name
	^ (ATActor new) name: name; yourself! !

ATBenchmarkGameSuite subclass: #ATBenchmarkGameSuiteTraced
	instanceVariableNames: 'actors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarkGameSuiteTraced methodsFor: 'accessing' stamp: 'StefanMarr 1/3/2012 22:08'!
actors
	^ actors! !

!ATBenchmarkGameSuiteTraced methodsFor: 'tracing' stamp: 'StefanMarr 1/4/2012 13:43'!
createActor: name
	| actor |
	actor := ATTracingActor new.
	actor name: name.
	actors add: actor.
	^ actor! !

!ATBenchmarkGameSuiteTraced methodsFor: 'initialization' stamp: 'StefanMarr 1/3/2012 22:08'!
initialize
	super initialize.
	actors := OrderedCollection new.! !

SMarkSuite subclass: #ATBenchmarks
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarks methodsFor: 'tracing' stamp: 'StefanMarr 1/4/2012 14:28'!
createActor: name
	^ ATActor new name: name; yourself! !

ATBenchmarks subclass: #ATMicroBenchmarks
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATMicroBenchmarks class methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/2/2012 17:52'!
defaultProblemSize
	^ 10000! !

!ATMicroBenchmarks methodsFor: 'benchmarking' stamp: 'StefanMarr 1/23/2013 13:00'!
benchLocalSend
	"In the omni version this one should be sensitive to field updates which will probably be measurable"
	| actor result cnt n |
	actor := self createActor: 'BenchExec'.
	
	n   := self problemSize.
	cnt := actor    adoptObject: ATMicroSubject new.
	
	result := actor evaluateAsync: [
		1 to: n do: [:i |
			cnt incCounter.
		].
		cnt counter
	].

	actor terminate await.

	^ result read! !

!ATMicroBenchmarks methodsFor: 'benchmarking' stamp: 'StefanMarr 1/23/2013 13:00'!
benchRemoteSend
	| actor cntActor cnt result n |
	actor    := self createActor: 'BenchExec'.
	cntActor := self createActor: 'Counter'.
	
	n   := self problemSize.
	cnt := cntActor adoptObject: ATMicroSubject new.
	
	result := actor evaluateAsync: [
		1 to: n do: [:i |
			cnt incCounter.
		].
		cnt counter
	].
	
	actor    terminate await.
	cntActor terminate await.

	^ result read! !

!ATMicroBenchmarks methodsFor: 'benchmarking' stamp: 'StefanMarr 1/23/2013 13:00'!
benchRemoteSendWithManyArguments
	| actor cntActor cnt result n |
	actor    := self createActor: 'BenchExec'.
	cntActor := self createActor: 'Counter'.
	
	n   := self problemSize.
	cnt := cntActor adoptObject: ATMicroSubject new.
	
	result := actor evaluateAsync: [
		1 to: n do: [:i |
			cnt process: i a: i b: i c: i d: i e: i f: i g: i h: i i: i.
		].
		cnt counter
	].

	actor    terminate await.
	cntActor terminate await.

	^ result read! !

ATMicroBenchmarks subclass: #ATMicroBenchmarksTraced
	instanceVariableNames: 'actors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATMicroBenchmarksTraced methodsFor: 'accessing' stamp: 'StefanMarr 1/3/2012 22:23'!
actors
	^ actors! !

!ATMicroBenchmarksTraced methodsFor: 'tracing' stamp: 'StefanMarr 1/4/2012 14:28'!
createActor: name
	| actor |
	actor := ATTracingActor new.
	actor name: name.
	actors add: actor.
	^ actor! !

!ATMicroBenchmarksTraced methodsFor: 'initialization' stamp: 'StefanMarr 1/3/2012 22:23'!
initialize
	super initialize.
	actors := OrderedCollection new.! !

OstObject subclass: #ATMicroSubject
	instanceVariableNames: 'cnt'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATMicroSubject methodsFor: 'accessing' stamp: 'StefanMarr 1/2/2012 14:32'!
counter
	^ cnt! !

!ATMicroSubject methodsFor: 'testing helpers' stamp: 'StefanMarr 1/2/2012 14:31'!
incCounter
	cnt := cnt + 1.! !

!ATMicroSubject methodsFor: 'initialization' stamp: 'StefanMarr 1/2/2012 14:31'!
initialize
	super initialize.
	cnt := 0.! !

!ATMicroSubject methodsFor: 'testing helpers' stamp: 'StefanMarr 1/2/2012 14:41'!
process: z a: a b: b c: c d: d e: e f: f g: g h: h i: i
	cnt := cnt + 1.! !

SMarkLoops subclass: #ATBenchLoops
	instanceVariableNames: 'actor omniDomain'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchLoops class methodsFor: 'class initialization' stamp: 'StefanMarr 9/8/2012 09:44'!
initialize
	OstObject omnifyClass: self.! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:20'!
benchATArrayAccess
	| promise |
	
	promise := actor evaluateAsync: [
		self benchArrayAccess.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:21'!
benchATClassVarBinding
	| promise |
	
	promise := actor evaluateAsync: [
		self benchClassVarBinding.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:21'!
benchATFloatLoop
	| promise |
	
	promise := actor evaluateAsync: [
		self benchFloatLoop.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:21'!
benchATInstVarAccess
	| promise |
	
	promise := actor evaluateAsync: [
		self benchInstVarAccess.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:21'!
benchATIntLoop
	| promise |
	
	promise := actor evaluateAsync: [
		self benchIntLoop.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:21'!
benchATSend
	| promise |
	
	promise := actor evaluateAsync: [
		self benchSend.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/8/2012 09:21'!
benchATSendWithManyArguments
	| promise |
	
	promise := actor evaluateAsync: [
		self benchSendWithManyArguments.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 9/12/2012 13:28'!
benchArrayAccess
	| i array obj |
	
	array := OstArray new: 1.
	obj   := OstObject new.
	
	i := self problemSize.
	[i > 0] whileTrue: [
		array at: 1.
		array at: 1 put: obj.
		
		i := i - 1.
	].! !

!ATBenchLoops methodsFor: 'tracing' stamp: 'StefanMarr 1/4/2012 14:26'!
createActor: name
	^ ATActor new name: name; yourself! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 8/29/2012 18:03'!
omniDomain
	<omniUnenforced>
	^ omniDomain! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 1/3/2012 14:04'!
omniDomain: aDomain
	omniDomain := aDomain! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector
	<omniUnenforced>
	^ omniDomain requestExecutionOf: aSelector on: self.! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector lookup: cls
	<omniUnenforced>
	^ omniDomain requestExecutionOf: aSelector lookup: cls on: self.! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector with: p1
	<omniUnenforced>
	^ omniDomain requestExecution: p1 of: aSelector on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector with: p1 with: p2
	<omniUnenforced>
	^ omniDomain requestExecution: p1 with: p2 of: aSelector on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3
	<omniUnenforced>
	^ omniDomain
		requestExecution: p1
		with: p2
		with: p3
		of: aSelector
		on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4
	<omniUnenforced>
	^ omniDomain
		requestExecution: p1
		with: p2
		with: p3
		with: p4
		of: aSelector
		on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4 with: p5
	<omniUnenforced>
	^ omniDomain
		requestExecution: p1
		with: p2
		with: p3
		with: p4
		with: p5
		of: aSelector 
		on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:14'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4 with: p5 with: p6
	<omniUnenforced>
	^ omniDomain
		requestExecution: p1
		with: p2
		with: p3
		with: p4
		with: p5
		with: p6
		of: aSelector
		on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:13'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4 with: p5 with: p6 with: p7
	<omniUnenforced>
	^ omniDomain
		requestExecution: p1
		with: p2
		with: p3
		with: p4
		with: p5
		with: p6
		with: p7
		of: aSelector
		on: self! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:13'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4 with: p5 with: p6 with: p7 with: p8
	<omniUnenforced>
	^ omniDomain requestExecutionOf: aSelector on: self with: p1 with: p2 with: p3 with: p4 with: p5 with: p6 with: p7 with: p8! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:13'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4 with: p5 with: p6 with: p7 with: p8 with: p9
	<omniUnenforced>
	^ omniDomain requestExecutionOf: aSelector on: self with: p1 with: p2 with: p3 with: p4 with: p5 with: p6 with: p7 with: p8 with: p9! !

!ATBenchLoops methodsFor: 'omni reflection' stamp: 'StefanMarr 7/18/2012 22:13'!
requestExecutionOf: aSelector with: p1 with: p2 with: p3 with: p4 with: p5 with: p6 with: p7 with: p8 with: p9 with: p10
	<omniUnenforced>
	^ omniDomain
		requestExecution: p1
		with: p2
		with: p3
		with: p4
		with: p5
		with: p6
		with: p7
		with: p8 with: p9 with: p10
		of: aSelector
		on: self! !

!ATBenchLoops methodsFor: 'running' stamp: 'StefanMarr 9/8/2012 09:21'!
setUp
	actor := self createActor: 'BenchExec'.
	actor adoptObject: self.! !

!ATBenchLoops methodsFor: 'running' stamp: 'StefanMarr 1/22/2013 23:47'!
tearDown
	actor terminate.! !

ATBenchLoops subclass: #ATBenchLoopsTraced
	instanceVariableNames: 'actors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchLoopsTraced methodsFor: 'accessing' stamp: 'StefanMarr 1/3/2012 20:36'!
actors
	^ actors! !

!ATBenchLoopsTraced methodsFor: 'tracing' stamp: 'StefanMarr 9/8/2012 09:38'!
createActor: name
	| a |
	a := ATTracingActor new.
	a name: name.
	actors add: a.
	^ a! !

!ATBenchLoopsTraced methodsFor: 'initialization' stamp: 'StefanMarr 1/3/2012 20:36'!
initialize
	super initialize.
	actors := OrderedCollection new.! !

OstTestCase subclass: #ATBenchmarkTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarkTests methodsFor: 'asserting' stamp: 'StefanMarr 8/6/2012 12:45'!
assert: expectedA or: expectedB equals: actual
	| isEqual |
	isEqual := (expectedA = actual) or: [expectedB = actual].
	^ self
		assert: isEqual
		description: [
			String streamContents: [:stream | 
				stream
					nextPutAll: 'Expected ';
					nextPutAll: (expectedA printStringLimitedTo: 10);
					nextPutAll: ' or ';
					nextPutAll: (expectedB printStringLimitedTo: 10);
					nextPutAll: ' but was ';
					nextPutAll: (actual printStringLimitedTo: 10);
					nextPutAll: '.']]! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:48'!
testATArrayAccess
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	bench benchATArrayAccess.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 8/6/2012 12:46'!
testATBinaryTrees
	| bench actors treeMsgCnt benchMsgCnt |
	bench := ATBenchmarkGameSuiteTraced new.
	self assert: -1 equals: bench benchATBinaryTrees.
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 2692 or: 2693 	equals: (actors at: 1) numberOfProcessedMessages. "Tree actor"
	self assert: 1 or: 2 			equals: (actors at: 2) numberOfProcessedMessages. "Bench actor"
	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:48'!
testATClassVarBinding
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	bench benchATClassVarBinding.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 8/6/2012 12:46'!
testATFannkuchRedux
	| bench actors |
	bench := ATBenchmarkGameSuiteTraced new.
	self assert: 4 equals: bench benchATFannkuchRedux.
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 312 or: 313 	equals: (actors at: 1) numberOfProcessedMessages. "Gen actor"
	self assert: 1 or: 2 			equals: (actors at: 2) numberOfProcessedMessages. "Bench actor"
	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 8/6/2012 12:47'!
testATFasta
	| atBench result actors |
	atBench := ATBenchmarkGameSuiteTraced new.
	result := atBench benchATFasta.
	
	self assert: result equals: BGFasta fasta.
	
	actors := atBench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 20010 or: 20011 	equals: (actors at: 1) numberOfProcessedMessages. "randomness actor"
	self assert: 2 or: 3 				equals: (actors at: 2) numberOfProcessedMessages. "bench exec actor"
	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:48'!
testATFloatLoop
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	bench benchATFloatLoop.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:49'!
testATInstVarAccess
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	bench benchATInstVarAccess.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:50'!
testATIntLoop
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	self assert: #done equals: bench benchATIntLoop.
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages. "loop actor"! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 8/6/2012 12:48'!
testATNBody
	| bench result actors bodyMessageCnt execMsgCnt |
	bench := ATBenchmarkGameSuiteTraced new.
	result := bench benchATNBody.
	
	self assert: (((result at: 2) asString) beginsWith: '-0.169087605').
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	bodyMessageCnt := (actors at: 1) numberOfProcessedMessages.
	execMsgCnt := (actors at: 2) numberOfProcessedMessages.
	
	self assert: BGNBody defaultProblemSize + 2 or: BGNBody defaultProblemSize + 3 equals: bodyMessageCnt.
	self assert: 1 or: 2 equals: execMsgCnt. "benchmark exec actor"! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:49'!
testATSend
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	bench benchATSend.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 9/8/2012 09:50'!
testATSendWithManyArguments
	| bench actors |
	bench := ATBenchLoopsTraced new setUp; yourself.
	bench benchATSendWithManyArguments.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 13:01'!
testLocalSend
	| bench actors result |
	bench := ATMicroBenchmarksTraced new.
	result := bench benchLocalSend.
	
	self assert: ATMicroBenchmarks defaultProblemSize
	     equals: result.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 2 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 4/1/2012 12:21'!
testRandomStreamActors
	| randomnessActor benchActor suite streamFact promise |
	suite := ATBenchmarkGameSuite new.
	randomnessActor := suite createActor: 'Randomness'.
	benchActor      := suite createActor: 'BenchExec'.
	
	streamFact := randomnessActor adoptObject: BGRepeatStreamFactory new.
	
	promise := benchActor evaluateAsync: [ | stream str |
		str :=	'GGCCGGGCGCGGTGGCTCACGCCTGTAATCCCAGCACTTTGG',
				'GAGGCCGAGGCGGGCGGATCACCTGAGGTCAGGAGTTCGAGA',
				'CCAGCCTGGCCAACATGGTGAAACCCCGTCTCTACTAAAAAT',
				'ACAAAAATTAGCCGGGCGTGGTGGCGCGCGCCTGTAATCCCA',
				'GCTACTCGGGAGGCTGAGGCAGGAGAATCGCTTGAACCCGGG',
				'AGGCGGAGGTTGCAGTGAGCCGAGATCGCGCCACTGCACTCC',
				'AGCCTGGGCGACAGAGCGAGACTCCGTCTCAAAAA'.
		stream := streamFact to: 2000
	            			on:	str.
		stream next. ].
	
	self assert: $G equals: promise read.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 13:02'!
testRemoteSend
	| bench actors result |
	bench := ATMicroBenchmarksTraced new.
	result:= bench benchRemoteSend.
	
	self assert: ATMicroBenchmarks defaultProblemSize
	     equals: result.
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 2          equals: (actors at: 1) numberOfProcessedMessages. "counting actor"
	self assert: result + 2 equals: (actors at: 2) numberOfProcessedMessages. "counter actor"
	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 13:02'!
testRemoteSendWithManyArguments
	| bench result actors |
	bench := ATMicroBenchmarksTraced new.
	result:= bench benchRemoteSendWithManyArguments.
	
	self assert: ATMicroBenchmarks defaultProblemSize
	     equals: result.
	
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 2          equals: (actors at: 1) numberOfProcessedMessages. "counting actor"
	self assert: result + 2 equals: (actors at: 2) numberOfProcessedMessages. "counter actor"
	! !
ATBenchLoops initialize!
